@@ -925,11 +925,15 @@ exchange_delegates (ExchangeAccount *account, GtkWidget *parent)
 	delegates->dialog = gtk_dialog_new_with_buttons (
 		_("Delegates"),
 		NULL,
-		GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK, GTK_RESPONSE_OK,
 		NULL);
 
+#if !GTK_CHECK_VERSION(2,90,7)
+	g_object_set (delegates->dialog, "has-separator", FALSE, NULL);
+#endif
+
 	dialog_vbox1 = gtk_dialog_get_content_area (GTK_DIALOG (delegates->dialog));
 	gtk_widget_show (dialog_vbox1);
 
